.. paquo documentation

Welcome to PAQUO
================

`Paquo` (**PA**\ thological **QU**\ path **O**\ bsession) is a python library
for interacting with `QuPath <https://qupath.github.io/>`_.

Its goal is to provide a pythonic interface to important features of QuPath,
and to make creating and working with QuPath projects intuitive for python
programmers.

We strive to make your lives as easy as possible: If `Paquo` is not pythonic,
unintuitive, slow or if its documentation is confusing, it's a bug in
`Paquo`. Feel free to report any issues or feature requests in the issue
tracker on the
`github <https://github.com/bayer-science-for-a-better-life/paquo>`_.

This page hosts the documentation for version "|version|".

.. warning::
    Paquo is undergoing heavy development right now and things might change
    frequently. Watch the github repository to stay up to date.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   configuration
   quickstart
   api
